// components/QuickGame/login.js
var myApp = getApp();
var autoTimer = null;
Component({

  lifetimes: {
    attached: function() {
      console.log('has attached QG_LOGIN');

      wx.setStorageSync('productCode',this.data.productcode);
      wx.setStorageSync('channelCode', this.data.channelcode);
      wx.setStorageSync('host', this.data.host);
      wx.setStorageSync('fullscreen', this.data.fullscreen);

      var systemSetting = wx.getSystemSetting();
      this.data.screenType = systemSetting.deviceOrientation;

      var buttonArea = wx.getMenuButtonBoundingClientRect();
      var nowTops = buttonArea.top;
      if(this.data.fullscreen == 'false' || this.data.fullscreen == false){
        nowTops = 10;
      }
      this.setData({buttonTop:nowTops});

      var userInfo = wx.getStorageSync('userInfo');
      var loginByToken = false;
      var that = this;
      that.data.loginEnd = false;
      if(userInfo != '' && userInfo != undefined && userInfo != null && typeof(userInfo) == 'object'){
        loginByToken = true;
        this.setData({userInfo:userInfo,loginByToken:loginByToken,autoLoginSec:3,showSaveUsername:userInfo.userData.username});
        //触发自动登录
        that.autoLogin();

        autoTimer = setInterval(function(){
          var nowSec = that.data.autoLoginSec;
          var thisSec = parseInt(nowSec) - 1;
          if(thisSec >= 0){
            that.setData({autoLoginSec:thisSec});
            return;
          }
          clearInterval(autoTimer);

          that.autoLoginCheck();

        },1000)
      }
    },
    detached: function() {
      // 在组件实例被从页面节点树移除时执行
    },
  },

  /**
   * 组件的属性列表
   */
  properties: {
    host:{
      type:String,
      value:'http://quickgame.sdk.quicksdk.net'
    },
    logo:{
      type:String,
      value:'true',
    },
    fullscreen:{
      type:String,
      value:"false",
    },
    removeunamelogin:{
      type:String,
      value:'false',
    },
    productcode: {
      type: String,
      value: '',
    },
    channelcode: {
      type: String,
      value: 'defaults',
    }
  },

  /**
   * 组件的初始数据
   */
  data: {
    showPage:1,//1登录页 
    agreement:'',
    privacy:'',
    indexAgreeStatus:false,
    username:'',
    password:'',
    showSaveUsername:'',
    loginButtonDisableStatus:false,
    userInfo:null,
    loginByToken:false,
    autoLoginSec:3,
    loginEnd:false,
    trueName:'',
    idnum:'',
    autoLoginError:'',
    buttonTop:50,
    screenType:'portrait'
  },

  /**
   * 组件的方法列表
   */
  methods: {

    tipsAgreement:function(){
      wx.showToast({
        title: '请阅读底部《用户使用协议》和《隐私协议》并同意相关条款',
        icon:'none'
      })
    },

    clearLocalUserInfo:function(){

    },

    //验证authToken
    autoLogin:function(){
      var token = this.data.userInfo.authToken;
      if(token == undefined || token == '' || token == null){
        that.data.userInfo = null;
        return;
      }

      //验证token
      var that = this;
      wx.request({
        url: that.data.host + '/wxmini/autoLogin',
        method:'GET',
        timeout:5000,
        data:{productCode:that.data.productcode,channelCode:that.data.channelcode,authToken:token},
        dataType:'json',
        success:function(result){
          
          try{
           var status = result.data.result;
           var userInfo = result.data.data;
          }catch(e){
            var status = false;
            var userInfo = null;
          }

          //清除本地token
          if(!status || userInfo == null){
            that.clearLocalUserInfo();
            that.data.userInfo = null;
            
            try{
              var autoLoginError = result.data.error.message;
            }catch(e){
              var autoLoginError = '';
            }
            that.data.autoLoginError = autoLoginError;
            return;
          }

          that.data.userInfo = userInfo;
          //记录到cache
          wx.setStorageSync('userInfo', userInfo);
          
        },
        fail:function(){

        },
        timeout:5000
      });

    },

    autoLoginCheck:function(){
      console.log("auto login ...");
      var that = this;
      var loginByToken = this.data.loginByToken;
      if(loginByToken == false){
        return;
      }
      var userInfo = this.data.userInfo;

      if(userInfo == null){
        var tips = that.data.autoLoginError;
        if(tips == ''){
          wx.showToast({
            title: '自动登录已过期',
            icon:'error',
          })
        }else{
          wx.showModal({
            title: '提示',
            content:tips,
          })
        }

        return this.setData({showPage:1,loginByToken:false});
      }

      var returnData = that.createNotifyData();
      if(returnData != null){
        that.sendSuccessNotify(returnData);
      }
    },

    toPage_useId:function(e){
      var type = e.currentTarget.dataset.type;

      if(type == 4 && this.data.indexAgreeStatus == false){
        return wx.showToast({
          icon:'none',
          title: '请阅读底部《用户使用协议》和《隐私协议》并同意相关条款',
        })
      }


      this.setData({showPage:type});

      if(type == 2 || type == 3){
        this.loadAgreement();
      }

    },

    checkInputStatus:function(){
    
      if(this.data.username.toString().length >= 4 && this.data.username.toString().length <= 20 && this.data.password.toString().length >= 4 && this.data.password.toString().length <= 20){
        this.setData({loginButtonDisableStatus:false});
      }else{
        this.setData({loginButtonDisableStatus:true});
      }
    },

    selectAgree:function(e){
      var that = this;
      var nowStatus = !that.data.indexAgreeStatus;
      this.setData({indexAgreeStatus:nowStatus});
    },

    loadAgreement:function(){
      var that = this;
      wx.request({
        url: that.data.host + '/wxmini/agreement/productCode/' + this.data.productcode,
        method:'GET',
        timeout:5000,
        data:{productCode:that.data.productcode,channelCode:that.data.channelcode},
        dataType:'json',
        success:function(result){
          if(result.data && result.data.data){
            var agreement = result.data.data.agreement ? result.data.data.agreement : '';
            var privacy = result.data.data.privacy ? result.data.data.privacy : '';
            console.log(agreement);
            that.setData({privacy:privacy,agreement:agreement});
          }
        },
        fail:function(){

        },
        timeout:5000
      });
    },

    changeAccount:function(){
      this.setData({loginByToken:false});
      clearInterval(autoTimer);
    },

    bindKeyInput_username:function(e){
      this.data.username = e.detail.value;
      this.checkInputStatus();
    },
  
    bindKeyInput_password:function(e){
      this.data.password = e.detail.value;
      this.checkInputStatus();
    },

    bindKeyInput_trueName:function(e){
      this.data.trueName = e.detail.value;
    },
  
    bindKeyInput_idnum:function(e){
      this.data.idnum = e.detail.value;
    },

    submitTrueName:function(){
      var trueName = this.data.trueName;
      var idnum = this.data.idnum;
      var that = this;
      if(trueName.length < 2 ){
        return wx.showToast({
          title: '姓名格式错误',
          icon:'error'
        })
      }

      if(idnum.length != 15 && idnum.length != 18 ){
        return wx.showToast({
          title: '身份证格式错误',
          icon:'error'
        })
      }

      //进行实名认证
      wx.showLoading({
        title: '正在认证',
      })

      wx.request({
        url: that.data.host + '/wxmini/checkRealName',
        method:'GET',
        timeout:15000,
        data:{productCode:that.data.productcode,channelCode:that.data.channelcode,uid:that.data.userInfo.userData.uid,realName:that.data.trueName,peopleId:that.data.idnum},
        dataType:'json',
        success:function(result){
          wx.hideLoading();
          if(!result.data.result){
            wx.showToast({
              title: result.data.error.message,
              icon:'error',
              timeout:2000
            })
            return;
          }
         
          try{
            var age = result.data.data.age;
          }catch(e){
            var age = 0;
          }

          if(age >= 18){
            that.data.userInfo.id = 0;
            that.data.userInfo.isAdult = true;
            that.data.userInfo.checkRealName = 0;
            that.data.userInfo.uAge = age;
            that.data.userInfo.message = "";
            that.data.userInfo.ckPlayTime = 0;
            wx.setStorageSync('userInfo', that.data.userInfo);
          }
          
          var returnData = that.createNotifyData();
          if(returnData != null){
            that.sendSuccessNotify(returnData);
          }

        },
        fail:function(){
          wx.hideLoading();
          wx.showToast({
            title: '实名失败请重试',
            icon:'error'
          })
        },
        complete:function(){
          
        }
      })

    },

    createNotifyData:function(){

      var userInfo = this.data.userInfo;
      if(userInfo == null){
        return null;
      }

      var userData = {};
      userData.uid = userInfo.userData.uid;
      userData.username = userInfo.userData.username;
      userData.token = userInfo.authToken;
      userData.isLogin = true;
      userData.age = userInfo.uAge;
      userData.isAdult = userInfo.isAdult;

      var returnData = {};
      returnData.status = true;
      returnData.data = userData;
      return returnData;
    },

    cancelLogin:function(){
      this.triggerEvent('logincancel', {status:false,message:'点击取消登录按钮'}, {})
    },

    sendSuccessNotify:function(data){
      var that = this;

      //检查防沉迷
      var isAdult = this.data.userInfo.isAdult;
      var errorId = this.data.userInfo.id;
      var tips = this.data.userInfo.message;
      var checkRealName = this.data.userInfo.checkRealName;
      if(errorId == 40040){

        //若未实名 则弹出实名认证界面
        if(checkRealName == 2){
          this.setData({showPage:6,loginByToken:false});
          return;
        }

        this.setData({showPage:5,adultTips:tips,loginByToken:false});
        return;
      }

      //检查踢下线
      var timeleft = parseInt(this.data.userInfo.timeleft);
      console.log("[QuickGame]可游戏时间" + timeleft);
      if(!isNaN(timeleft) && timeleft > 0){
        setTimeout(function(){
          that.triggerEvent('logout', data, {})
        },timeleft*1000);
      }

      //显示顶部提示
      that.triggerEvent('loginsuccess', data, {})
      that.setData({loginEnd:true});
    },

    beginLogin:function(){
      var that = this;

      //验证长度
      if(that.data.username.length < 4 || that.data.username.length > 26){
        return wx.showToast({
          title: '账号长度错误',
          icon:'error'
        })
      }

      if(that.data.password.length < 4 || that.data.password.length > 26){
        return wx.showToast({
          title: '密码长度错误',
          icon:'error'
        })
      }

      wx.login({
        success: res => {
          // 发送 res.code 到后台换取 openId, sessionKey, unionId
          wx.showLoading({
            title: '正在验证..',
          })
          
          wx.request({
            url: that.data.host + '/wxmini/wxminibind',
            method:'GET',
            timeout:5000,
            data:{username:that.data.username,password:that.data.password,code:res.code,productCode:that.data.productcode,channelCode:that.data.channelcode},
            dataType:'json',
            timeout:300000,
            success:function(result){
              wx.hideLoading();
              if(!result.data.result){
                wx.showToast({
                  title: result.data.error.message,
                  icon:'error',
                  timeout:2000
                })
                return;
              }
             
              that.setData({userInfo:result.data.data});

              //记录到cache
              wx.setStorageSync('userInfo', result.data.data);
              
              var returnData = that.createNotifyData();
              if(returnData != null){
                that.sendSuccessNotify(returnData);
              }
            },
            fail:function(){
              wx.hideLoading();
              wx.showToast({
                title: '授权失败',
                icon:'error'
              })
            },
            complete:function(){
              
            }
          })
        },
        fail:function(){
          wx.showToast({
            title: '验证失败请重试',
            icon: 'error',
            duration: 2000
          })
        }
      })
    },

    getPhoneNumber (e) {
      var phonecode = e.detail.code;
      if(phonecode == undefined){
        if(this.data.showPage != 4){
          this.setData({showPage:4});
        }
        return;
      }
  
      //调用login授权
      var that = this;
      wx.showLoading({
        title: '正在授权',
      })
      wx.request({
        url: that.data.host + '/wxmini/wxminiPhonebind',
        method:'GET',
        timeout:5000,
        data:{phonecode:phonecode,productCode:that.data.productcode,channelCode:that.data.channelcode},
        dataType:'json',
        success:function(result){
          wx.hideLoading();
          if(!result.data.result){
            wx.showModal({
              title: '提示',
              content:result.data.error.message
            })
            return;
          }
  
          that.setData({userInfo:result.data.data});

          //记录到cache
          wx.setStorageSync('userInfo', result.data.data);

          var returnData = that.createNotifyData();
          if(returnData != null){
            that.sendSuccessNotify(returnData);
          }
          
          
        },
        fail:function(){
          wx.hideLoading();
          wx.showToast({
            title: '授权失败',
            icon:'error'
          })
        },
        complete:function(){
          
        }
      })
    },

  }
})
